# babel-plugin-transform-semantic-ui-react-imports

[![Build Status](https://travis-ci.org/skleeschulte/babel-plugin-transform-semantic-ui-react-imports.svg?branch=master)](https://travis-ci.org/skleeschulte/babel-plugin-transform-semantic-ui-react-imports)

This plugin can convert module imports from `semantic-ui-react` to default imports. Example:

    // Input:
    import { Button, Container } from 'semantic-ui-react';

    // Output:
    import Button from 'semantic-ui-react/dist/es/elements/Button/Button.js';
    import Container from 'semantic-ui-react/dist/es/elements/Container/Container.js';

In addition, the plugin can add import statements for LESS files from `semantic-ui-less`. For the example input above, this would produce:

    import 'semantic-ui-less/definitions/elements/button.less';
    import 'semantic-ui-less/definitions/elements/container.less';

The LESS imports can e.g. be useful in conjunction with Webpack and [semantic-ui-less-module-loader](https://www.npmjs.com/package/semantic-ui-less-module-loader).

Both, the conversion of module imports and adding LESS imports, can be enabled/disabled separately. The import type for default imports can also be configured (e.g. `es` or `commonjs`).

## Example repository

You can find an example of how to use this plugin together with the
semantic-ui-less-module-loader in the
[tailored-semantic-ui-react-bundles-with-webpack](https://github.com/skleeschulte/tailored-semantic-ui-react-bundles-with-webpack)
repository.

## Installation

    npm install babel-plugin-transform-semantic-ui-react-imports --save-dev

Depending on how you use the plugin, you also need to install [semantic-ui-react](https://www.npmjs.com/package/semantic-ui-react) and/or [semantic-ui-less](https://www.npmjs.com/package/semantic-ui-less) (see below).

## Usage

Add the plugin to your Babel configuration (e.g. in .babelrc):

    {
        "plugins": ["transform-semantic-ui-react-imports"]
    }

### Plugin options

The plugin supports the following options (these are the default values):

    {
        "plugins": [
            [
                "transform-semantic-ui-react-imports", {
                    "convertMemberImports": true,
                    "importType": "es",
                    "addLessImports": false
                }
            ]
        ]
    }

#### convertMemberImports (default: `true`)

If true, member imports from `semantic-ui-react` are converted to default imports.

This requires `semantic-ui-react` to be installed.

#### importType (default: `'es'`)

This must be either the name of a folder below `semantic-ui-react/dist` or `src`. `'es'`, `'commonjs'` or `'umd'`:

- `importType='es'` example output:  
  `import Button from 'semantic-ui-react/dist/es/elements/Button/Button.js';`
- `importType='src'` example output:  
  `import Button from 'semantic-ui-react/src/elements/Button/Button.js';`

#### addLessImports (default: `false`)

If true, imports for LESS files from `semantic-ui-less` will be added according to what is required from `semantic-ui-react`. Also works with `convertMemberImports=false`.

This requires `semantic-ui-less` to be installed.

### Combining with babel-plugin-lodash

babel-plugin-lodash is an alternative to this plugin for cherry-picking
imports from semantic-ui-react. However, I found that bundles generated
with this plugin and `convertMemberImports=true` are slightly smaller
than when using babel-plugin-lodash. (I just did a quick comparison with
a few components imported from semantic-ui-react though, and no thorough
testing. I also do not know where the difference in the bundle sizes
comes from.) Most importantly, **you should not use both plugins to
convert member imports from semantic-ui-react**.

E.g., **do not use the following configuration**:

    {
        "plugins": [
            "transform-semantic-ui-react-imports",
            ["lodash", { "id": ["semantic-ui-react"] }]
        ]
    }

For the input

    import { Button } from 'semantic-ui-react';`

this would produce the undesired output (on Windows):

    import _Button from 'semantic-ui-react/dist\\commonjs\\elements\\Button/Button'; // generated by babel-plugin-lodash
    import Button from 'semantic-ui-react/dist/es/elements/Button/Button.js'; // generated by babel-plugin-transform-semantic-ui-react-imports

If you prefer to use babel-plugin-lodash to convert the imports from
semantic-ui-react and still want to use this plugin to add imports from
semantic-ui-less, this is possible:

    {
        "plugins": [
            ["transform-semantic-ui-react-imports", {
                "convertMemberImports": false,
                "addLessImports": true
            }],
            ["lodash", { "id": ["semantic-ui-react"] }]
        ]
    }

## Running the tests

    git clone https://github.com/skleeschulte/babel-plugin-transform-semantic-ui-react-imports.git
    cd babel-plugin-transform-semantic-ui-react-imports
    npm install
    npm run test
